# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 0.3.2   | :white_check_mark: |
| <= 0.3.1   | :x:                |

## Reporting a Vulnerability

Please file a bug report issue.
